==> kendo-dropdowns-vue-wrapper-2022.1.301-dev.301.tgz: package/docs/autocomplete/index.md <==
---
title: Overview
page_title: AutoComplete Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI AutoComplete wrapper for Vue delivers and use the component in Vue projects."
slug: overview_autocomplete
canonicalLink: "https://www.telerik.com/kendo-vue-ui/components/dropdowns/autocomplete/"
position: 1
---

<WrapperBanner link="/kendo-vue-ui/components/dropdowns/autocomplete"></WrapperBanner>

# AutoComplete Overview

The AutoComplete provides suggestions depending on the typed text.

It is a richer version of the `<input>` element and provides suggestions depending on the typed text.

The AutoComplete wrapper for Vue is a client-side wrapper for the [Kendo UI AutoComplete](https://docs.telerik.com/kendo-ui/api/javascript/ui/autocomplete) widget.

<div data-component="StartFreeTrialSection"></div>

## Basic Usage

The following example demonstrates the AutoComplete in action.

{% meta height:350 %}
{% embed_file autocomplete/basic/main.vue preview %}
{% embed_file autocomplete/basic/main.js %}
{% endmeta %}

## Functionality and Features

* [Data binding]({% slug databinding_autocomplete %})
* [Filtering]({% slug filtering_autocomplete %})
* [Virtualization]({% slug virtualization_autocomplete %})
* [Grouping]({% slug grouping_autocomplete %})
* [Templates]({% slug templates_autocomplete %})
* [Keyboard navigation]({% slug keyboard_navigation_autocomplete %})
* [RTL support]({% slug rtl_support_autocomplete %})

## Events

The following example demonstrates basic AutoComplete events. You can subscribe to [all AutoComplete events](https://docs.telerik.com/kendo-ui/api/javascript/ui/autocomplete#events) by the handler name.

{% meta height:350 %}
{% embed_file autocomplete/events/main.vue preview %}
{% embed_file autocomplete/events/main.js %}
{% endmeta %}

## Suggested Links

* [Kendo UI AutoComplete for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/autocomplete/overview)
* [API Reference of the AutoComplete Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/autocomplete)

==> kendo-dropdowns-vue-wrapper-2022.2.621-dev.722.tgz: package/docs/autocomplete/index.md <==
---
title: Overview
page_title: AutoComplete Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI AutoComplete wrapper for Vue delivers and use the component in Vue projects."
slug: overview_autocomplete_wrapper
canonicalLink: "https://www.telerik.com/kendo-vue-ui/components/dropdowns/autocomplete/"
position: 1
---

<WrapperBanner link="/kendo-vue-ui/components/dropdowns/autocomplete"></WrapperBanner>

# AutoComplete Overview

The AutoComplete provides suggestions depending on the typed text.

It is a richer version of the `<input>` element and provides suggestions depending on the typed text.

The AutoComplete wrapper for Vue is a client-side wrapper for the [Kendo UI AutoComplete](https://docs.telerik.com/kendo-ui/api/javascript/ui/autocomplete) widget.

<div data-component="StartFreeTrialSection"></div>

## Basic Usage

The following example demonstrates the AutoComplete in action.

{% meta height:350 %}
{% embed_file autocomplete/basic/main.vue preview %}
{% embed_file autocomplete/basic/main.js %}
{% endmeta %}

## Functionality and Features

* [Data binding]({% slug databinding_autocomplete_wrapper %})
* [Filtering]({% slug filtering_autocomplete_wrapper %})
* [Virtualization]({% slug virtualization_autocomplete_wrapper %})
* [Grouping]({% slug grouping_autocomplete_wrapper %})
* [Templates]({% slug templates_autocomplete_wrapper %})
* [Keyboard navigation]({% slug keyboard_navigation_autocomplete_wrapper %})
* [RTL support]({% slug rtl_support_autocomplete_wrapper %})

## Events

The following example demonstrates basic AutoComplete events. You can subscribe to [all AutoComplete events](https://docs.telerik.com/kendo-ui/api/javascript/ui/autocomplete#events) by the handler name.

{% meta height:350 %}
{% embed_file autocomplete/events/main.vue preview %}
{% embed_file autocomplete/events/main.js %}
{% endmeta %}

## Suggested Links

* [Kendo UI AutoComplete for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/autocomplete/overview)
* [API Reference of the AutoComplete Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/autocomplete)
